@@ -1,29 +1,43 @@
 import typing
 
+from .abc import (
+    ABCThrowable,
+    ABCMetadata,
+    ABCValidator,
+)
+from .config import (
+    Config,
+)
 from .loader import (
     EnvironmentLoader,
-    EnvironmentLoaderMeta
+    EnvironmentLoaderMeta,
 )
 from .metadata import (
-    _TMetadata,
-    ABCMetadata,
-    ConfigurableMetadata,
     DefaultMetadata,
+    ConfigurableMetadata,
+)
+from .types import (
+    TMetadata,
 )
 from .validators import (
-    ABCValidator,
     MetadataValidator,
     validate,
 )
+from .errors import (
+    LenvError,
+)
 
 __all__: typing.Sequence[str] = (
+    'ABCThrowable',
+    'ABCMetadata',
+    'ABCValidator',
+    'Config',
     'EnvironmentLoader',
     'EnvironmentLoaderMeta',
-    '_TMetadata',
-    'ABCMetadata',
+    'TMetadata',
     'ConfigurableMetadata',
     'DefaultMetadata',
-    'ABCValidator',
     'MetadataValidator',
     'validate',
+    'LenvError',
 )
